@@ -339,8 +339,8 @@ CacheDatabase::getRegisteredNumbers (GVRegisteredNumberArray &listNumbers)
     while (query.next ())
     {
         GVRegisteredNumber num;
-        num.strDisplayName = query.value(0).toString();
-        num.strNumber      = query.value(1).toString();
+        num.strName        = query.value(0).toString();
+        num.strDescription = query.value(1).toString();
         num.chType         = query.value(2).toString()[0].toAscii ();
         listNumbers += num;
     }
@@ -368,8 +368,8 @@ CacheDatabase::putRegisteredNumbers (const GVRegisteredNumberArray &listNumbers)
             strQ = QString ("INSERT INTO " GV_REG_NUMS_TABLE
                             " (" GV_RN_NAME ", " GV_RN_NUM ", " GV_RN_TYPE ") "
                             "VALUES ('%1', '%2', %3)")
-                    .arg (num.strDisplayName)
-                    .arg (num.strNumber)
+                    .arg (num.strName)
+                    .arg (num.strDescription)
                     .arg (num.chType);
             query.exec (strQ);
         }
